@@ -33,10 +33,12 @@ struct thread_data;
 #include "options.h"
 #include "profile.h"
 #include "time.h"
+#include "gettime.h"
 #include "lib/getopt.h"
 #include "lib/rand.h"
 #include "server.h"
 #include "stat.h"
+#include "flow.h"
 
 #ifdef FIO_HAVE_GUASI
 #include <guasi.h>
@@ -257,6 +259,11 @@ struct thread_options {
 	unsigned int uid;
 	unsigned int gid;
 
+	int flow_id;
+	int flow;
+	int flow_watermark;
+	unsigned int flow_sleep;
+
 	unsigned int sync_file_range;
 };
 
@@ -469,6 +476,8 @@ struct thread_data {
 	unsigned int total_err_count;
 	int first_error;
 
+	struct fio_flow *flow;
+
 	/*
 	 * Can be overloaded by profiles
 	 */
@@ -580,8 +589,9 @@ static inline int should_fsync(struct thread_data *td)
 extern int __must_check parse_options(int, char **);
 extern int parse_jobs_ini(char *, int, int);
 extern int parse_cmd_line(int, char **);
-extern int exec_run(void);
+extern int fio_backend(void);
 extern void reset_fio_state(void);
+extern void clear_io_state(struct thread_data *);
 extern int fio_options_parse(struct thread_data *, char **, int);
 extern void fio_keywords_init(void);
 extern int fio_cmd_option_parse(struct thread_data *, const char *, char *);
